@@ -112,14 +112,18 @@ class dispatcher(object):
             web.restore_presets()
 
             # Get view script and view module
-            print(">> EXT: ", self.extension)
             sc = script(self.cwd, request.path, extension=self.extension)
             sc.get_module()
 
             # Process Response, and get payload
             response = web.process(request, environ, self.cwd)
+
         except NotFound:
             response = NotFound()
+
+        except OSError:
+            response = NotFound()
+
         finally:
             # Fire post response events
             request.view_events.fire_post_response(request, response)
